View Source AshSqids.Type (ash_sqids v0.2.0)
AshSqids.Type implements Ash.Type behaviour in a module that uses it.
By default Sqids options are looked up by doing Application.compile_env!(:ash_sqids, [:opts, __MODULE__]).
use AshSqids.Type accepts two optional exclusive options to change that - opts and config:
optsprovides options directly and disables config lookup from environment.configspecifies a key to be used instead of a module name.
Having either options in config environment or in opts is required, even if you want to use default ones
(in that case pass empty list []).
Sqids options include alphabet, min_length and blocklist. It is recommended to provide alphabet.
It can be a default one - abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789 - but just shuffled.